@@ -63,5 +63,5 @@ def enlarge_mask(module: torch.nn.Module, max_sequence_length: int) -> torch.nn.
             (max_sequence_length, max_sequence_length),  # type: ignore
             dtype=torch.uint8,
             device=old_mask.device)).view(1, 1, max_sequence_length, max_sequence_length)  # type: ignore
-    setattr(module, "bias", new_mask)
+    setattr(module, 'bias', new_mask)
     return module
