@@ -23,14 +23,16 @@ if TYPE_CHECKING:
 
 log = logging.getLogger(__name__)
 
-__all__ = ["NoOpModelClass", "NoOpModel"]
+__all__ = ['NoOpModelClass', 'NoOpModel']
 
 
 class NoOpModelClass(ComposerModel):
-    """Dummy model used for testing. The NoOpModel algorithm uses this to replace a ComposerModel.
+    """Dummy model used for performance measurements.
+
+    The :class:`.NoOpModel` algorithm uses this class to replace a :class:`torch.nn.Module`.
 
     Args:
-        original_model (ComposerModel): model to replace.
+        original_model (torch.nn.Module): Model to replace.
     """
 
     def __init__(self, original_model: torch.nn.Module):
@@ -64,7 +66,11 @@ class NoOpModelClass(ComposerModel):
 
 
 class NoOpModel(Algorithm):
-    """Runs on :attr:`Event.INIT` and replaces the model with a dummy model of type NoOpModelClass."""
+    """Runs on :attr:`Event.INIT` and replaces the model with a dummy :class:`.NoOpModelClass` instance."""
+
+    def __init__(self):
+        # No arguments
+        pass
 
     def match(self, event: Event, state: State) -> bool:
         return event == Event.INIT
