@@ -21,7 +21,7 @@ import torch.utils.data
 
 from composer.utils.string_enum import StringEnum
 
-__all__ = ["Batch", "PyTorchScheduler", "JSON", "MemoryFormat", "BreakEpochException"]
+__all__ = ['Batch', 'PyTorchScheduler', 'JSON', 'MemoryFormat', 'BreakEpochException']
 
 Batch = Any
 
@@ -57,7 +57,7 @@ class MemoryFormat(StringEnum):
         PRESERVE_FORMAT: A way to tell operations to make the output tensor to have the same memory format as the input
             tensor.
     """
-    CONTIGUOUS_FORMAT = "contiguous_format"
-    CHANNELS_LAST = "channels_last"
-    CHANNELS_LAST_3D = "channels_last_3d"
-    PRESERVE_FORMAT = "preserve_format"
+    CONTIGUOUS_FORMAT = 'contiguous_format'
+    CHANNELS_LAST = 'channels_last'
+    CHANNELS_LAST_3D = 'channels_last_3d'
+    PRESERVE_FORMAT = 'preserve_format'
