@@ -8,22 +8,20 @@ from __future__ import annotations
 import collections.abc
 import operator
 import pathlib
-import time
 from enum import IntEnum
 from functools import reduce
 from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence, Union
 
-import coolname
 import torch
 
-from composer.utils import dist, ensure_tuple
+from composer.utils import ensure_tuple
 from composer.utils.file_helpers import format_name_with_dist
 
 if TYPE_CHECKING:
     from composer.core.state import State
     from composer.loggers.logger_destination import LoggerDestination
 
-__all__ = ["LoggerDestination", "Logger", "LogLevel", "format_log_data_value"]
+__all__ = ['LoggerDestination', 'Logger', 'LogLevel', 'format_log_data_value']
 
 
 class LogLevel(IntEnum):
@@ -31,6 +29,7 @@ class LogLevel(IntEnum):
 
     Logging destinations use the LogLevel to determine whether to record a given
     metric or state change.
+
     Attributes:
         FIT: Logged once per training run.
         EPOCH: Logged once per epoch.
@@ -66,56 +65,18 @@ class Logger:
         state (State): The training state.
         destinations (LoggerDestination | Sequence[LoggerDestination], optional):
             The logger destinations, to where logging data will be sent. (default: ``None``)
-        run_name (str, optional): The name for this training run.
-
-            If not specified, the timestamp will be combined with a :doc:`coolname <coolname:index>` like the
-            following:
-
-            .. testsetup:: composer.loggers.logger.Logger.__init__.run_name
-
-                import random
-                import coolname
-                import time
-
-                coolname.replace_random(random.Random(0))
-
-                original_time = time.time
-
-                time.time = lambda: 1647293526.1849217
-
-            .. doctest:: composer.loggers.logger.Logger.__init__.run_name
-
-                >>> logger = Logger(state=state, destinations=[])
-                >>> logger.run_name
-                '1647293526-electric-zebra'
-
-            .. testcleanup:: composer.loggers.logger.Logger.__init__.run_name
-
-                time.time = original_time
 
     Attributes:
         destinations (Sequence[LoggerDestination]):
             A sequence of :class:`~.LoggerDestination` to where logging calls will be sent.
-        run_name (str): The ``run_name``.
     """
 
     def __init__(
         self,
         state: State,
         destinations: Optional[Union[LoggerDestination, Sequence[LoggerDestination]]] = None,
-        run_name: Optional[str] = None,
     ):
         self.destinations = ensure_tuple(destinations)
-        if run_name is None:
-            # prefixing with the time so experiments sorted alphabetically will
-            # have the latest experiment last
-            run_name = str(int(time.time())) + "-" + coolname.generate_slug(2)
-            run_name_list = [run_name]
-            # ensure all ranks have the same experiment name
-            dist.broadcast_object_list(run_name_list)
-            run_name = run_name_list[0]
-        assert run_name is not None, "run name is set above if not specified."
-        self.run_name = run_name
         self._state = state
 
     def data(self, log_level: Union[str, int, LogLevel], data: Dict[str, Any]) -> None:
@@ -152,60 +113,28 @@ class Logger:
             overwrite (bool, optional): Whether to overwrite an existing artifact with the same ``artifact_name``.
                 (default: ``False``)
         """
-
         log_level = LogLevel(log_level)
-        file_path = format_name_with_dist(format_str=str(file_path), run_name=self.run_name)
+        file_path = format_name_with_dist(format_str=str(file_path), run_name=self._state.run_name)
         file_path = pathlib.Path(file_path)
         for destination in self.destinations:
             destination.log_file_artifact(
                 state=self._state,
                 log_level=log_level,
-                artifact_name=format_name_with_dist(format_str=artifact_name, run_name=self.run_name),
+                artifact_name=format_name_with_dist(format_str=artifact_name, run_name=self._state.run_name),
                 file_path=file_path,
                 overwrite=overwrite,
             )
 
-    def symlink_artifact(
-        self,
-        log_level: Union[str, int, LogLevel],
-        existing_artifact_name: str,
-        symlink_artifact_name: str,
-        overwrite: bool = False,
-    ):
-        """Symlink ``existing_artifact_name`` as ``symlink_artifact_name``.
-
-        Both ``existing_artifact_name`` and ``symlink_artifact_name`` can be specified as format strings.
-        See :func:`~.composer.utils.file_helpers.format_name_with_dist` for more information.
-
-        Args:
-            log_level (str | int | LogLevel): The log level, which can be a name, value, or instance of
-                :class:`LogLevel`.
-            existing_artifact_name (str): A format string for the name of symlinked artifact.
-            symlink_artifact_name (str): A format string for the symlink name of artifact.
-            overwrite (bool, optional): Whether to overwrite an existing artifact with the same ``symlink_artifact_name``.
-                (default: ``False``)
-        """
-
-        log_level = LogLevel(log_level)
-        for destination in self.destinations:
-            destination.log_symlink_artifact(
-                state=self._state,
-                log_level=log_level,
-                existing_artifact_name=format_name_with_dist(format_str=existing_artifact_name, run_name=self.run_name),
-                symlink_artifact_name=format_name_with_dist(format_str=symlink_artifact_name, run_name=self.run_name),
-                overwrite=overwrite,
-            )
-
     def data_fit(self, data: Dict[str, Any]) -> None:
-        """Helper function for ``self.data(LogLevel.FIT, data)``"""
+        """Helper function for ``self.data(LogLevel.FIT, data)``."""
         self.data(LogLevel.FIT, data)
 
     def data_epoch(self, data: Dict[str, Any]) -> None:
-        """Helper function for ``self.data(LogLevel.EPOCH, data)``"""
+        """Helper function for ``self.data(LogLevel.EPOCH, data)``."""
         self.data(LogLevel.EPOCH, data)
 
     def data_batch(self, data: Dict[str, Any]) -> None:
-        """Helper function for ``self.data(LogLevel.BATCH, data)``"""
+        """Helper function for ``self.data(LogLevel.BATCH, data)``."""
         self.data(LogLevel.BATCH, data)
 
 
@@ -214,21 +143,22 @@ def format_log_data_value(data: Any) -> str:
 
     Args:
         data: Data to format.
+
     Returns:
         str: ``data`` as a string.
     """
     if data is None:
-        return "None"
+        return 'None'
     if isinstance(data, str):
         return f"\"{data}\""
     if isinstance(data, int):
         return str(data)
     if isinstance(data, float):
-        return f"{data:.4f}"
+        return f'{data:.4f}'
     if isinstance(data, torch.Tensor):
-        if data.shape == tuple() or reduce(operator.mul, data.shape, 1) == 1:
+        if data.shape == () or reduce(operator.mul, data.shape, 1) == 1:
             return format_log_data_value(data.cpu().item())
-        return "Tensor of shape " + str(data.shape)
+        return 'Tensor of shape ' + str(data.shape)
     if isinstance(data, collections.abc.Mapping):
         output = ['{ ']
         for k, v in data.items():
@@ -236,9 +166,9 @@ def format_log_data_value(data: Any) -> str:
             v = format_log_data_value(v)
             output.append(f"\"{k}\": {v}, ")
         output.append('}')
-        return "".join(output)
+        return ''.join(output)
     if isinstance(data, collections.abc.Iterable):
-        return "[" + ", ".join(format_log_data_value(v) for v in data) + "]"
+        return '[' + ', '.join(format_log_data_value(v) for v in data) + ']'
 
     # Unknown format catch-all
     return str(data)
