@@ -12,28 +12,20 @@ import pathlib
 import queue
 import shutil
 import tempfile
-import textwrap
 import threading
 import time
 import uuid
 from multiprocessing.context import SpawnProcess
-from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
-
-from libcloud.common.types import LibcloudError
-from libcloud.storage.types import ObjectDoesNotExistError
-from requests.exceptions import ConnectionError
-from urllib3.exceptions import ProtocolError
+from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Type, Union
 
 from composer.core.state import State
 from composer.loggers.logger import Logger, LogLevel
 from composer.loggers.logger_destination import LoggerDestination
-from composer.utils import format_name_with_dist
-from composer.utils.file_helpers import get_file
-from composer.utils.object_store import ObjectStore
+from composer.utils import ObjectStore, ObjectStoreTransientError, dist, format_name_with_dist, get_file, retry
 
 log = logging.getLogger(__name__)
 
-__all__ = ["ObjectStoreLogger"]
+__all__ = ['ObjectStoreLogger']
 
 
 def _always_log(state: State, log_level: LogLevel, artifact_name: str):
@@ -42,21 +34,33 @@ def _always_log(state: State, log_level: LogLevel, artifact_name: str):
     return True
 
 
+def _build_object_store(object_store_cls: Type[ObjectStore], object_store_kwargs: Dict[str, Any]):
+    # error: Expected no arguments to "ObjectStore" constructor
+    return object_store_cls(**object_store_kwargs)  # type: ignore
+
+
 class ObjectStoreLogger(LoggerDestination):
-    """Logger destination that uploads artifacts to an object store.
+    r"""Logger destination that uploads artifacts to an object store.
 
     This logger destination handles calls to :meth:`~composer.loggers.logger.Logger.file_artifact`
-    and uploads files to an object store, such as AWS S3 or Google Cloud Storage.
+    and uploads files to :class:`.ObjectStore`, such as AWS S3 or Google Cloud Storage. To minimize the training
+    loop performance hit, it supports background uploads.
 
     .. testcode:: composer.loggers.object_store_logger.ObjectStoreLogger.__init__
 
+        from composer.loggers import ObjectStoreLogger
+        from composer.utils import LibcloudObjectStore
+
         object_store_logger = ObjectStoreLogger(
-            provider='s3',
-            container='my-bucket',
-            provider_kwargs={
-                'key': 'AKIA...',
-                'secret': '*********',
-                'region': 'ap-northeast-1',
+            object_store_cls=LibcloudObjectStore,
+            object_store_kwargs={
+                'provider': 's3',
+                'container': 'my-bucket',
+                'provider_kwargs=': {
+                    'key': 'AKIA...',
+                    'secret': '*********',
+                    'region': 'ap-northeast-1',
+                },
             },
         )
 
@@ -66,10 +70,6 @@ class ObjectStoreLogger(LoggerDestination):
             loggers=[object_store_logger],
         )
 
-    .. testcleanup:: composer.loggers.object_store_logger.ObjectStoreLogger.__init__
-
-        trainer.engine.close()
-
     .. note::
 
         This callback blocks the training loop to copy each artifact where ``should_log_artifact`` returns ``True``, as
@@ -83,46 +83,19 @@ class ObjectStoreLogger(LoggerDestination):
             always occurs in the background.
 
         *   Provide a RAM disk path for the ``upload_staging_folder`` parameter. Copying files to stage on RAM will be
-            faster than writing to disk. However, there must have sufficient excess RAM, or :exc:`MemoryError`\\s may
+            faster than writing to disk. However, there must have sufficient excess RAM, or :exc:`MemoryError`\s may
             be raised.
 
     Args:
-        provider (str): Cloud provider to use. Valid options are:
+        object_store_cls (Type[ObjectStore]): The object store class.
 
-            * :mod:`~libcloud.storage.drivers.atmos`
-            * :mod:`~libcloud.storage.drivers.auroraobjects`
-            * :mod:`~libcloud.storage.drivers.azure_blobs`
-            * :mod:`~libcloud.storage.drivers.backblaze_b2`
-            * :mod:`~libcloud.storage.drivers.cloudfiles`
-            * :mod:`~libcloud.storage.drivers.digitalocean_spaces`
-            * :mod:`~libcloud.storage.drivers.google_storage`
-            * :mod:`~libcloud.storage.drivers.ktucloud`
-            * :mod:`~libcloud.storage.drivers.local`
-            * :mod:`~libcloud.storage.drivers.minio`
-            * :mod:`~libcloud.storage.drivers.nimbus`
-            * :mod:`~libcloud.storage.drivers.ninefold`
-            * :mod:`~libcloud.storage.drivers.oss`
-            * :mod:`~libcloud.storage.drivers.rgw`
-            * :mod:`~libcloud.storage.drivers.s3`
+            As individual :class:`.ObjectStore` instances are not necessarily thread safe, each worker will construct
+            its own :class:`.ObjectStore` instance from ``object_store_cls`` and ``object_store_kwargs``.
 
-            .. seealso:: :doc:`Full list of libcloud providers <libcloud:storage/supported_providers>`
+        object_store_kwargs (Dict[str, Any]): The keyword arguments to construct ``object_store_cls``.
 
-        container (str): The name of the container (i.e. bucket) to use.
-        provider_kwargs (Dict[str, Any], optional):  Keyword arguments to pass into the constructor
-            for the specified provider. These arguments would usually include the cloud region
-            and credentials.
-
-            Common keys are:
-
-            * ``key`` (str): API key or username to be used (required).
-            * ``secret`` (str): Secret password to be used (required).
-            * ``secure`` (bool): Whether to use HTTPS or HTTP. Note: Some providers only support HTTPS, and it is on by default.
-            * ``host`` (str): Override hostname used for connections.
-            * ``port`` (int): Override port used for connections.
-            * ``api_version`` (str): Optional API version. Only used by drivers which support multiple API versions.
-            * ``region`` (str): Optional driver region. Only used by drivers which support multiple regions.
-
-            .. seealso:: :class:`libcloud.storage.base.StorageDriver`
+            As individual :class:`.ObjectStore` instances are not necessarily thread safe, each worker will construct
+            its own :class:`.ObjectStore` instance from ``object_store_cls`` and ``object_store_kwargs``.
 
         should_log_artifact ((State, LogLevel, str) -> bool, optional): A function to filter which artifacts
             are uploaded.
@@ -142,7 +115,7 @@ class ObjectStoreLogger(LoggerDestination):
             | ``{artifact_name}``    | The name of the artifact being logged.                |
             +------------------------+-------------------------------------------------------+
             | ``{run_name}``         | The name of the training run. See                     |
-            |                        | :attr:`.Logger.run_name`.                             |
+            |                        | :attr:`.State.run_name`.                              |
             +------------------------+-------------------------------------------------------+
             | ``{rank}``             | The global rank, as returned by                       |
             |                        | :func:`~composer.utils.dist.get_global_rank`.         |
@@ -199,26 +172,26 @@ class ObjectStoreLogger(LoggerDestination):
             If not specified, defaults to using a :func:`~tempfile.TemporaryDirectory`.
         use_procs (bool, optional): Whether to perform file uploads in background processes (as opposed to threads).
             Defaults to True.
+        num_attempts (int, optional): For operations that fail with a transient error, the number of attempts to make.
+            Defaults to 3.
     """
 
-    def __init__(
-        self,
-        provider: str,
-        container: str,
-        provider_kwargs: Optional[Dict[str, Any]] = None,
-        should_log_artifact: Optional[Callable[[State, LogLevel, str], bool]] = None,
-        object_name: str = '{artifact_name}',
-        num_concurrent_uploads: int = 4,
-        upload_staging_folder: Optional[str] = None,
-        use_procs: bool = True,
-    ) -> None:
-        self.provider = provider
-        self.container = container
-        self.provider_kwargs = provider_kwargs
+    def __init__(self,
+                 object_store_cls: Type[ObjectStore],
+                 object_store_kwargs: Dict[str, Any],
+                 should_log_artifact: Optional[Callable[[State, LogLevel, str], bool]] = None,
+                 object_name: str = '{artifact_name}',
+                 num_concurrent_uploads: int = 4,
+                 upload_staging_folder: Optional[str] = None,
+                 use_procs: bool = True,
+                 num_attempts: int = 3) -> None:
+        self.object_store_cls = object_store_cls
+        self.object_store_kwargs = object_store_kwargs
         if should_log_artifact is None:
             should_log_artifact = _always_log
         self.should_log_artifact = should_log_artifact
         self.object_name = object_name
+        self.num_attempts = num_attempts
         self._run_name = None
 
         if upload_staging_folder is None:
@@ -229,41 +202,81 @@ class ObjectStoreLogger(LoggerDestination):
             self._upload_staging_folder = upload_staging_folder
 
         if num_concurrent_uploads < 1:
-            raise ValueError("num_concurrent_uploads must be >= 1. Blocking uploads are not supported.")
+            raise ValueError('num_concurrent_uploads must be >= 1. Blocking uploads are not supported.')
         self._num_concurrent_uploads = num_concurrent_uploads
 
+        # There could be multiple upload workers uploading to the same object
+        # If multiple workers are uploading to the same object simultaneously (e.g. the checkpoint latest symlink file), then
+        # The object store might keep the earlier file rather than the latter file as the "latest" version
+
+        # To work around this, each object name can appear at most once in `self._file_upload_queue`
+        # The main separately keeps track of {object_name: tempfile_path} for each API call to self.log_file_artifact
+        # and then periodically transfers items from this dictionary onto the file upload queue
+
+        # Lock for modifying `logged_objects` or `enqueued_objects`
+        # These objects are used by threads on the main process only
+        self._object_lock = threading.Lock()
+
+        # Files that were logged but yet to be enqueued. Mapping of the object name to the (tempfile path, overwrite) for that object
+        self._logged_objects: Dict[str, Tuple[str, bool]] = {}
+
+        # Set of enqueued objects. This should keep track of everything in self._file_upload_queue with O(1) lookup
+        self._enqueued_objects: Set[str] = set()
+
+        # Thread that runs `self._enqueue_uploads`
+        self._enqueue_thread = None
+
         if use_procs:
             mp_ctx = multiprocessing.get_context('spawn')
             self._file_upload_queue: Union[queue.Queue[Tuple[str, str, bool]],
                                            multiprocessing.JoinableQueue[Tuple[str, str,
-                                                                               bool]]] = mp_ctx.JoinableQueue()
+                                                                               bool]],] = mp_ctx.JoinableQueue()
+            self._completed_queue: Union[queue.Queue[str], multiprocessing.JoinableQueue[str],] = mp_ctx.JoinableQueue()
             self._finished_cls: Union[Callable[[], multiprocessing._EventType], Type[threading.Event]] = mp_ctx.Event
             self._proc_class = mp_ctx.Process
         else:
             self._file_upload_queue = queue.Queue()
+            self._completed_queue = queue.Queue()
             self._finished_cls = threading.Event
             self._proc_class = threading.Thread
         self._finished: Optional[Union[multiprocessing._EventType, threading.Event]] = None
         self._workers: List[Union[SpawnProcess, threading.Thread]] = []
+        # the object store instance for the main thread. Deferring the construction of the object_store to first use.
+        self._object_store = None
+
+    @property
+    def object_store(self) -> ObjectStore:
+        """The :class:`.ObjectStore` instance for the main thread."""
+        if self._object_store is None:
+            self._object_store = _build_object_store(self.object_store_cls, self.object_store_kwargs)
+        return self._object_store
 
     def init(self, state: State, logger: Logger) -> None:
-        del state  # unused
+        del logger  # unused
         if self._finished is not None:
-            raise RuntimeError("The ObjectStoreLogger is already initialized.")
+            raise RuntimeError('The ObjectStoreLogger is already initialized.')
         self._finished = self._finished_cls()
-        self._run_name = logger.run_name
-        object_name_to_test = self._object_name(".credentials_validated_successfully")
-        _validate_credentials(self.provider, self.container, self.provider_kwargs, object_name_to_test)
-        assert len(self._workers) == 0, "workers should be empty if self._finished was None"
+        self._run_name = state.run_name
+        object_name_to_test = self._object_name('.credentials_validated_successfully')
+
+        # Create the enqueue thread
+        self._enqueue_thread = threading.Thread(target=self._enqueue_uploads, daemon=True)
+        self._enqueue_thread.start()
+
+        if dist.get_global_rank() == 0:
+            retry(ObjectStoreTransientError,
+                  self.num_attempts)(lambda: _validate_credentials(self.object_store, object_name_to_test))()
+        assert len(self._workers) == 0, 'workers should be empty if self._finished was None'
         for _ in range(self._num_concurrent_uploads):
             worker = self._proc_class(
                 target=_upload_worker,
                 kwargs={
-                    "file_queue": self._file_upload_queue,
-                    "is_finished": self._finished,
-                    "provider": self.provider,
-                    "container": self.container,
-                    "provider_kwargs": self.provider_kwargs,
+                    'file_queue': self._file_upload_queue,
+                    'is_finished': self._finished,
+                    'object_store_cls': self.object_store_cls,
+                    'object_store_kwargs': self.object_store_kwargs,
+                    'num_attempts': self.num_attempts,
+                    'completed_queue': self._completed_queue,
                 },
                 # The worker threads are joined in the shutdown procedure, so it is OK to set the daemon status
                 # Setting daemon status prevents the process from hanging if close was never called (e.g. in doctests)
@@ -280,68 +293,132 @@ class ObjectStoreLogger(LoggerDestination):
         del state, logger  # unused
         self._check_workers()
 
+    @property
+    def _all_workers_alive(self):
+        """Whether all workers are alive."""
+        return all(worker.is_alive() for worker in self._workers)
+
     def _check_workers(self):
         # Periodically check to see if any of the upload workers crashed
         # They would crash if:
         #   a) A file could not be uploaded, and the retry counter failed, or
         #   b) allow_overwrite=False, but the file already exists,
-        for worker in self._workers:
-            if not worker.is_alive():
-                raise RuntimeError("Upload worker crashed. Please check the logs.")
+        if not self._all_workers_alive:
+            raise RuntimeError('Upload worker crashed. Please check the logs.')
 
-    def log_file_artifact(self, state: State, log_level: LogLevel, artifact_name: str, file_path: pathlib.Path, *,
-                          overwrite: bool):
+    def log_file_artifact(
+        self,
+        state: State,
+        log_level: LogLevel,
+        artifact_name: str,
+        file_path: pathlib.Path,
+        *,
+        overwrite: bool,
+    ):
         if not self.should_log_artifact(state, log_level, artifact_name):
             return
         copied_path = os.path.join(self._upload_staging_folder, str(uuid.uuid4()))
         os.makedirs(self._upload_staging_folder, exist_ok=True)
         shutil.copy2(file_path, copied_path)
         object_name = self._object_name(artifact_name)
-        self._file_upload_queue.put_nowait((copied_path, object_name, overwrite))
+        with self._object_lock:
+            if object_name in self._logged_objects and not overwrite:
+                raise FileExistsError(f'Object {object_name} was already enqueued to be uploaded, but overwrite=False.')
+            self._logged_objects[object_name] = (copied_path, overwrite)
 
-    def log_symlink_artifact(self, state: State, log_level: LogLevel, existing_artifact_name: str,
-                             symlink_artifact_name: str, overwrite: bool):
-        """Object stores do not natively support symlinks, so we emulate symlinks by adding a .symlink file to the
-        object store, which is a text file containing the name of the object it is pointing to."""
-        # Only symlink if we're logging artifact to begin with
-        if not self.should_log_artifact(state, log_level, existing_artifact_name):
-            return
-        copied_path = os.path.join(self._upload_staging_folder, str(uuid.uuid4()))
-        os.makedirs(self._upload_staging_folder, exist_ok=True)
-        # Write artifact name into file to emulate symlink
-        with open(copied_path, 'w') as f:
-            f.write(existing_artifact_name)
-        # Add .symlink extension so we can identify as emulated symlink when downloading
-        object_name = self._object_name(symlink_artifact_name) + ".symlink"
-        self._file_upload_queue.put_nowait((copied_path, object_name, overwrite))
+    def _enqueue_uploads(self):
+        """Worker thread to enqueue uploads.
+
+        This thread does two things:
+
+        1.  It enqueues objects from ``self._logged_objects`` onto ``self._file_upload_queue``.
+        2.  It keeps ``self._enqueued_objects`` in sync with ``self._file_upload_queue`` by listening to ``self._completed_uploads``.
+        """
+        assert self._finished is not None
+        while True:
+            with self._object_lock:
+                # Remove all objects from self._enqueued_objects that have been successfully uploaded
+                while True:
+                    try:
+                        object_name = self._completed_queue.get_nowait()
+                    except queue.Empty:
+                        break
+                    self._enqueued_objects.remove(object_name)
+                    self._completed_queue.task_done()
+
+                # Enqueue all objects that are in self._logged_objects but not in self._file_upload_queue
+                objects_to_delete = []
+                for object_name, (copied_path, overwrite) in self._logged_objects.items():
+                    if object_name in self._enqueued_objects:
+                        continue
+                    self._file_upload_queue.put_nowait((copied_path, object_name, overwrite))
+                    objects_to_delete.append(object_name)
+                    self._enqueued_objects.add(object_name)
+                for object_name in objects_to_delete:
+                    del self._logged_objects[object_name]
+
+                #
+                if self._finished.is_set():
+                    if self._all_workers_alive:
+                        if len(self._logged_objects) == 0:
+                            # If finished (i.e. no more objects to be added to self._logged_objects) and all logged objects are
+                            # enqueued, then break
+                            break
+                    else:
+                        # If any worker died, then it's impossible to recover since the file was already popped off of the queue,
+                        # so break.Some files may not be uploaded.
+                        break
+
+            # Yield the lock, so it can be acquired by `self.log_file_artifact`
+            time.sleep(0.2)
 
     def get_file_artifact(
         self,
         artifact_name: str,
         destination: str,
-        chunk_size: int = 2**20,
+        overwrite: bool = False,
         progress_bar: bool = True,
     ):
-        object_store = ObjectStore(provider=self.provider,
-                                   container=self.container,
-                                   provider_kwargs=self.provider_kwargs)
         get_file(path=artifact_name,
                  destination=destination,
-                 object_store=object_store,
-                 chunk_size=chunk_size,
+                 object_store=self.object_store,
+                 overwrite=overwrite,
                  progress_bar=progress_bar)
 
     def post_close(self):
         # Cleaning up on post_close to ensure that all artifacts are uploaded
         if self._finished is not None:
             self._finished.set()
+
+        # First, ensure that all uploads are enqueued
+        if self._enqueue_thread is not None:
+            self._enqueue_thread.join()
+
+        # Then, ensure all workers have finished all uploads
         for worker in self._workers:
             worker.join()
+
+        # Clean up the tempdir
         if self._tempdir is not None:
             self._tempdir.cleanup()
+
+        # Reset all variables
         self._tempdir = None
         self._finished = None
         self._workers.clear()
+        self._enqueued_objects.clear()
+        self._logged_objects.clear()
+        assert self._file_upload_queue.empty()
+
+        # Empty the completed queue
+        while True:
+            try:
+                self._completed_queue.get_nowait()
+            except queue.Empty:
+                break
+            self._completed_queue.task_done()
+
+        self._enqueue_thread = None
 
     def get_uri_for_artifact(self, artifact_name: str) -> str:
         """Get the object store provider uri for an artfact.
@@ -353,13 +430,12 @@ class ObjectStoreLogger(LoggerDestination):
             str: The uri corresponding to the uploaded location of the artifact.
         """
         obj_name = self._object_name(artifact_name)
-        provider_prefix = f"{self.provider}://{self.container}/"
-        return provider_prefix + obj_name.lstrip("/")
+        return self.object_store.get_uri(obj_name.lstrip('/'))
 
     def _object_name(self, artifact_name: str):
         """Format the ``artifact_name`` according to the ``object_name_string``."""
         if self._run_name is None:
-            raise RuntimeError("The run name is not set. It should have been set on Event.INIT.")
+            raise RuntimeError('The run name is not set. It should have been set on Event.INIT.')
         key_name = format_name_with_dist(
             self.object_name,
             run_name=self._run_name,
@@ -371,34 +447,33 @@ class ObjectStoreLogger(LoggerDestination):
 
 
 def _validate_credentials(
-    provider: str,
-    container: str,
-    provider_kwargs: Optional[Dict[str, Any]],
+    object_store: ObjectStore,
     object_name_to_test: str,
 ) -> None:
-    # Validates the credentails by attempting to touch a file in the bucket
-    # raises a LibcloudError if there was a credentials failure.
-    object_store = ObjectStore(provider=provider, container=container, provider_kwargs=provider_kwargs)
-    object_store.upload_object_via_stream(
-        obj=b"credentials_validated_successfully",
-        object_name=object_name_to_test,
-    )
+    # Validates the credentials by attempting to touch a file in the bucket
+    # raises an error if there was a credentials failure.
+    with tempfile.NamedTemporaryFile('wb') as f:
+        f.write(b'credentials_validated_successfully')
+        object_store.upload_object(
+            object_name=object_name_to_test,
+            filename=f.name,
+        )
 
 
 def _upload_worker(
     file_queue: Union[queue.Queue[Tuple[str, str, bool]], multiprocessing.JoinableQueue[Tuple[str, str, bool]]],
+    completed_queue: Union[queue.Queue[str], multiprocessing.JoinableQueue[str]],
     is_finished: Union[multiprocessing._EventType, threading.Event],
-    provider: str,
-    container: str,
-    provider_kwargs: Optional[Dict[str, Any]],
+    object_store_cls: Type[ObjectStore],
+    object_store_kwargs: Dict[str, Any],
+    num_attempts: int,
 ):
-    """A long-running function to handle uploading files to the object store specified by (``provider``, ``container``,
-    ``provider_kwargs``).
+    """A long-running function to handle uploading files to the object store.
 
     The worker will continuously poll ``file_queue`` for files to upload. Once ``is_finished`` is set, the worker will
     exit once ``file_queue`` is empty.
     """
-    object_store = ObjectStore(provider=provider, container=container, provider_kwargs=provider_kwargs)
+    object_store = _build_object_store(object_store_cls, object_store_kwargs)
     while True:
         try:
             file_path_to_upload, object_name, overwrite = file_queue.get(block=True, timeout=0.5)
@@ -407,46 +482,27 @@ def _upload_worker(
                 break
             else:
                 continue
-        if not overwrite:
-            try:
-                object_store.get_object_size(object_name)
-            except ObjectDoesNotExistError:
-                # Good! It shouldn't exist.
-                pass
-            else:
-                # Exceptions will be detected on the next batch_end or epoch_end event
-                raise FileExistsError(
-                    textwrap.dedent(f"""\
-                    {provider}://{container}/{object_name} already exists,
-                    but allow_overwrite was set to False."""))
-        log.info("Uploading file %s to %s://%s/%s", file_path_to_upload, object_store.provider_name,
-                 object_store.container_name, object_name)
-        retry_counter = 0
-        while True:
-            try:
-                object_store.upload_object(
-                    file_path=file_path_to_upload,
-                    object_name=object_name,
-                )
-            except (LibcloudError, ProtocolError, TimeoutError, ConnectionError) as e:
-                if isinstance(e, LibcloudError):
-                    # The S3 driver does not encode the error code in an easy-to-parse manner
-                    # So first checking if the error code is non-transient
-                    is_transient_error = any(x in str(e) for x in ("408", "409", "425", "429", "500", "503", '504'))
-                    if not is_transient_error:
-                        raise e
-                if retry_counter < 4:
-                    retry_counter += 1
-                    # exponential backoff
-                    sleep_time = 2**(retry_counter - 1)
-                    log.warning("Request failed. Sleeping %s seconds and retrying",
-                                sleep_time,
-                                exc_info=e,
-                                stack_info=True)
-                    time.sleep(sleep_time)
-                    continue
-                raise e
+        uri = object_store.get_uri(object_name)
 
+        # defining as a function-in-function to use decorator notation with num_attempts as an argument
+        @retry(ObjectStoreTransientError, num_attempts=num_attempts)
+        def upload_file():
+            if not overwrite:
+                try:
+                    object_store.get_object_size(object_name)
+                except FileNotFoundError:
+                    # Good! It shouldn't exist.
+                    pass
+                else:
+                    # Exceptions will be detected on the next batch_end or epoch_end event
+                    raise FileExistsError(f'Object {uri} already exists, but allow_overwrite was set to False.')
+            log.info('Uploading file %s to %s', file_path_to_upload, uri)
+            object_store.upload_object(
+                object_name=object_name,
+                filename=file_path_to_upload,
+            )
             os.remove(file_path_to_upload)
             file_queue.task_done()
-            break
+            completed_queue.put_nowait(object_name)
+
+        upload_file()
