@@ -8,4 +8,4 @@ from composer.models.bert.bert_hparams import BERTForClassificationHparams as BE
 from composer.models.bert.bert_hparams import BERTHparams as BERTHparams
 from composer.models.bert.model import BERTModel as BERTModel
 
-__all__ = ["BERTModel", "BERTHparams", "BERTForClassificationHparams"]
+__all__ = ['BERTModel', 'BERTHparams', 'BERTForClassificationHparams']
