@@ -5,7 +5,7 @@
 from composer.models.classify_mnist.mnist_hparams import MnistClassifierHparams as MnistClassifierHparams
 from composer.models.classify_mnist.model import MNIST_Classifier as MNIST_Classifier
 
-__all__ = ["MNIST_Classifier", "MnistClassifierHparams"]
+__all__ = ['MNIST_Classifier', 'MnistClassifierHparams']
 
 _task = 'Image Classification'
 _dataset = 'MNIST'
