@@ -9,7 +9,7 @@ import yahp as hp
 
 from composer.models.model_hparams import ModelHparams
 
-__all__ = ["EfficientNetB0Hparams"]
+__all__ = ['EfficientNetB0Hparams']
 
 
 @dataclass
@@ -21,13 +21,13 @@ class EfficientNetB0Hparams(ModelHparams):
         drop_connect_rate (float, optional): Probability of dropping a sample within a block before identity connection. Default: ``0.2``.
     """
     drop_connect_rate: float = hp.optional(
-        doc="Probability of dropping a sample within a block before identity connection.",
+        doc='Probability of dropping a sample within a block before identity connection.',
         default=0.2,
     )
 
     def initialize_object(self):
         if self.num_classes is None:
-            raise ValueError("EfficientNet requires num_classes to be specified.")
+            raise ValueError('EfficientNet requires num_classes to be specified.')
 
         from composer.models.efficientnetb0.model import EfficientNetB0
         return EfficientNetB0(num_classes=self.num_classes, drop_connect_rate=self.drop_connect_rate)
