@@ -19,7 +19,7 @@ from composer.loss import loss_registry
 from composer.metrics import CrossEntropy
 from composer.models import ComposerModel
 
-__all__ = ["ComposerClassifier"]
+__all__ = ['ComposerClassifier']
 
 log = logging.getLogger(__name__)
 
@@ -51,33 +51,33 @@ class ComposerClassifier(ComposerModel):
 
     num_classes: Optional[int] = None
 
-    def __init__(self, module: torch.nn.Module, loss_name: str = "soft_cross_entropy") -> None:
+    def __init__(self, module: torch.nn.Module, loss_name: str = 'soft_cross_entropy') -> None:
         super().__init__()
         self.train_acc = Accuracy()
         self.val_acc = Accuracy()
         self.val_loss = CrossEntropy()
         self.module = module
         if loss_name not in loss_registry.keys():
-            raise ValueError(f"Unrecognized loss function: {loss_name}. Please ensure the "
-                             "specified loss function is present in composer.loss.loss.py")
+            raise ValueError(f'Unrecognized loss function: {loss_name}. Please ensure the '
+                             'specified loss function is present in composer.loss.loss.py')
         self._loss_fxn = loss_registry[loss_name]
 
-        if hasattr(self.module, "num_classes"):
-            self.num_classes = getattr(self.module, "num_classes")
+        if hasattr(self.module, 'num_classes'):
+            self.num_classes = getattr(self.module, 'num_classes')
 
         if loss_name == 'binary_cross_entropy_with_logits':
-            log.warning("UserWarning: Using `binary_cross_entropy_loss_with_logits` "
-                        "without using `initializers.linear_log_constant_bias` can degrade "
-                        "performance. "
-                        "Please ensure you are using `initializers. "
-                        "linear_log_constant_bias`.")
+            log.warning('UserWarning: Using `binary_cross_entropy_loss_with_logits` '
+                        'without using `initializers.linear_log_constant_bias` can degrade '
+                        'performance. '
+                        'Please ensure you are using `initializers. '
+                        'linear_log_constant_bias`.')
 
     def loss(self, outputs: Any, batch: Any, *args, **kwargs) -> Tensor:
         _, targets = batch
         if not isinstance(outputs, Tensor):  # to pass typechecking
-            raise ValueError("Loss expects input as Tensor")
+            raise ValueError('Loss expects input as Tensor')
         if not isinstance(targets, Tensor):
-            raise ValueError("Loss does not support multiple target Tensors")
+            raise ValueError('Loss does not support multiple target Tensors')
         return self._loss_fxn(outputs, targets, *args, **kwargs)
 
     def metrics(self, train: bool = False) -> Union[Metric, MetricCollection]:
