@@ -10,6 +10,7 @@ from composer.utils.file_helpers import (create_symlink_file, ensure_folder_has_
                                          get_file, is_tar)
 from composer.utils.import_helpers import MissingConditionalImportError, import_object
 from composer.utils.iter_helpers import IteratorFileStream, ensure_tuple, map_collection
+from composer.utils.misc import is_notebook
 from composer.utils.object_store import (LibcloudObjectStore, ObjectStore, ObjectStoreTransientError, S3ObjectStore,
                                          SFTPObjectStore)
 from composer.utils.retrying import retry
@@ -28,6 +29,7 @@ __all__ = [
     'SFTPObjectStore',
     'MissingConditionalImportError',
     'import_object',
+    'is_notebook',
     'StringEnum',
     'load_checkpoint',
     'save_checkpoint',
